@@ -1,9 +1,12 @@
+import inspect
 
 import requests
+from MSApi.ObjectMS import ObjectMS
+
 from MSApi.MSLowApi import MSLowApi, error_handler, caching
 
 from MSApi.Meta import Meta
-from MSApi.Organization import Organization, Account
+from MSApi.Organization import Organization
 from MSApi.Template import Template
 from MSApi.Product import Product
 from MSApi.Service import Service
@@ -13,32 +16,13 @@ from MSApi.PriceType import PriceType
 from MSApi.CompanySettings import CompanySettings
 from MSApi.Bundle import Bundle
 from MSApi.Variant import Variant
-from MSApi.Employee import Employee
 from MSApi.documents.CustomerOrder import CustomerOrder
-
 from MSApi.exceptions import *
+import MSApi as MSApi_module
 
 
 class MSApi(MSLowApi):
 
-    __objects_dict = {
-        'product': Product,
-        'organization': Organization,
-        'template': Template,
-        'productfolder': ProductFolder,
-        'discount': Discount,
-        'specialpricediscount': SpecialPriceDiscount,
-        'accumulationdiscount': AccumulationDiscount,
-        'service': Service,
-        'companysettings': CompanySettings,
-        'bundle': Bundle,
-        'variant': Variant,
-        'employee': Employee,
-        'account': Account,
-        'customerorder': CustomerOrder
-
-    }
-
     @classmethod
     def get_company_settings(cls) -> CompanySettings:
         """Запрос на получение Настроек компании."""
@@ -53,22 +37,27 @@ class MSApi(MSLowApi):
         error_handler(response)
         return PriceType(response.json())
 
+    @classmethod
+    def get_object_type(cls, obj_type_name) -> type:
+        for member in inspect.getmembers(MSApi_module):
+            if type(member[1]) is not type:
+                continue
+            if not issubclass(member[1], ObjectMS):
+                continue
+            if not hasattr(member[1], "_type_name"):
+                continue
+            if member[1].get_typename() == obj_type_name:
+                return member[1]
+        raise MSApiException("Object type \"{}\" not found".format(obj_type_name))
+
     @classmethod
     def get_object_by_meta(cls, meta: Meta):
-        obj_type = cls.__objects_dict.get(meta.get_type())
-        if obj_type is None:
-            raise MSApiException(f"Unknown object type \"{meta.get_type()}\"")
-        response = cls._auch_get_by_href(meta.get_href())
-        error_handler(response)
-        return obj_type(response.json())
+        return cls.get_object_type(meta.get_type())
 
     @classmethod
     def get_object_by_json(cls, json_data):
         meta = Meta(json_data.get('meta'))
-        obj_type = cls.__objects_dict.get(meta.get_type())
-        if obj_type is None:
-            raise MSApiException(f"Unknown object type \"{meta.get_type()}\"")
-        return obj_type(json_data)
+        return cls.get_object_type(meta.get_type())
 
     @classmethod
     def get_object_by_href(cls, href):
