@@ -4,3 +4,5 @@ from MSApi.mixin.ProductfolderMixin import *
 from MSApi.mixin.SalePricesMixin import *
 from MSApi.mixin.GenListMixin import *
 from MSApi.mixin.RequestByIdMixin import *
+from MSApi.mixin.StateMixin import *
+from MSApi.mixin.CreateNewMixin import *
